# Lutop

## Introduction

Welcome to Lutop (Lightweight System Monitor), a terminal-based system monitoring application inspired by Unix `top` command and designed using Python and curses library.

## Installation
Install lutop using pip 

```bash
pip install lutop
```

## Usage
To start lutop, simply run the following command in your terminal:

```bash
lutop
```

![Usage Demo](media/demo.gif)

### Contributing
We welcome contributions! If you discover a bug in this project, please feel free to open an issue to discuss the changes you would like to propose.
